@@ -1,15 +1,14 @@
 """ ClinicalOmicsDB: Bridging the gap between next-generation clinical omics data and machine learning
 Reference: Chang In Moon, Byron Jia, Bing Zhang
 Paper link: TBD
-Last updated Date: October 6th 2022
 Code author: Chang In Moon (moonchangin@gmail.com)
 -----------------------------
 """
-__version__ = '0.3.0'
+__version__ = '0.4.5'
 
 import io
 import pandas as pd
-from database_download import download, get_dataset_link
+# from database_download import biomarker_download_sheet
 from file_download import download_text as _download_text
 from exceptions import BaseError, BaseWarning, InvalidParameterError, NoInternetError, OldPackageVersionWarning
 
